@@ -748,9 +748,9 @@ char * make_uname(const char * org)
 
 	if (i == sizeof_array(exts))
 	{
+		out = xstrmrg(org, ".out");
 		error("cannot guess original name for '%s' -- using '%s'", 
 			org, out);
-		out = xstrmrg(org, ".out");
 	}
 	else
 	{
@@ -817,7 +817,7 @@ void do_sign(void)
 	int i, n, ext, hlen;
 
 	const buf_t * title = 0;
-	const char * in, * p;
+	const char * p, * in = 0;
 	buf_t in_buf;
 	
 	hash_val_t * h;
